aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB
diff options
context:
space:
mode:
authorTristan Darricau <github@nicofuma.fr>2015-01-20 23:08:30 +0100
committerTristan Darricau <github@nicofuma.fr>2015-01-21 08:41:02 +0100
commit7fef91afd28290ce268f671eb525dedf5ade944d (patch)
tree8d91bf49e6b4eadb7077396ebfa68a9bf3c2d5e4 /phpBB
parent8ef238ea73b481a717d8b68fb1fd7d1b8799d7f2 (diff)
downloadforums-7fef91afd28290ce268f671eb525dedf5ade944d.tar
forums-7fef91afd28290ce268f671eb525dedf5ade944d.tar.gz
forums-7fef91afd28290ce268f671eb525dedf5ade944d.tar.bz2
forums-7fef91afd28290ce268f671eb525dedf5ade944d.tar.xz
forums-7fef91afd28290ce268f671eb525dedf5ade944d.zip
[ticket/13361] Rename exception to runtime_exception
PHPBB3-13361
Diffstat (limited to 'phpBB')
-rw-r--r--phpBB/phpbb/exception/http_exception.php2
-rw-r--r--phpBB/phpbb/exception/runtime_exception.php (renamed from phpBB/phpbb/exception/exception.php)6
2 files changed, 4 insertions, 4 deletions
diff --git a/phpBB/phpbb/exception/http_exception.php b/phpBB/phpbb/exception/http_exception.php
index f733462a05..0e6ffe4f59 100644
--- a/phpBB/phpbb/exception/http_exception.php
+++ b/phpBB/phpbb/exception/http_exception.php
@@ -18,7 +18,7 @@ use Symfony\Component\HttpKernel\Exception\HttpExceptionInterface;
/**
* Class http_exception
*/
-class http_exception extends exception implements HttpExceptionInterface
+class http_exception extends runtime_exception implements HttpExceptionInterface
{
/**
* Http status code.
diff --git a/phpBB/phpbb/exception/exception.php b/phpBB/phpbb/exception/runtime_exception.php
index 077d0d258a..6568bbf86f 100644
--- a/phpBB/phpbb/exception/exception.php
+++ b/phpBB/phpbb/exception/runtime_exception.php
@@ -14,11 +14,11 @@
namespace phpbb\exception;
/**
- * Class exception
+ * Class runtime_exception
*
* Define an exception which support a language var as message.
*/
-class exception extends \RuntimeException implements exception_interface
+class runtime_exception extends \RuntimeException implements exception_interface
{
/**
* Parameters to use with the language var.
@@ -32,7 +32,7 @@ class exception extends \RuntimeException implements exception_interface
*
* @param string $message The Exception message to throw (must be a language variable).
* @param array $parameters The parameters to use with the language var.
* @param \Exception $previous The previous exception used for the exception chaining.
* @param integer $code The Exception code.
*/
public function __construct($message = "", array $parameters = array(), \Exception $previous = null, $code = 0)
@@ -32,7 +32,7 @@ class exception extends \RuntimeException implements exception_interface
* @param string $message The Exception message to throw (must be a language variable).
* @param array $parameters The parameters to use with the language var.
- * @param \Exception $previous The previous exception used for the exception chaining.
+ * @param \Exception $previous The previous runtime_exception used for the runtime_exception chaining.
* @param integer $code The Exception code.
*/